Module: R7
- Defined in:
- lib/argv.rb,
lib/version.rb
Constant Summary collapse
- VERSION =
'0.2.2'
Class Method Summary collapse
-
.get_argv ⇒ Object
Returns an array of command-line arguments, including quotation marks used to encapulate arguments with spaces.
Class Method Details
.get_argv ⇒ Object
Returns an array of command-line arguments, including quotation marks used to encapulate arguments with spaces.
3 4 5 6 |
# File 'lib/argv.rb', line 3 def self.get_argv argv = ARGV argv.each_index { |i| argv[i] = "'#{argv[i]}'" if argv[i].include?(" ") } end |